@@ -32,14 +32,14 @@ options:
     description:
       - Offset query parameter. Offset/starting row.
         Indexed from 1.
-    type: float
+    type: int
   limit:
     description:
       - >
         Limit query parameter. Number of reserve pools
         to be retrieved. Default is 25 if not specified.
         Maximum allowed limit is 500.
-    type: float
+    type: int
   ignoreInheritedGroups:
     description:
       - >
@@ -86,8 +86,8 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
     siteId: string
-    offset: 0
-    limit: 0
+    offset: 1      # Must be >= 1
+    limit: 25     # Must be >= 1
     ignoreInheritedGroups: true
     poolUsage: string
     groupName: string
