@@ -230,7 +230,7 @@ EXAMPLES = r'''
 '''
 
 RETURN = r'''
-api_repsonse:
+api_response:
   description: The API response output returned by the specified resource.
   returned: always
   type: dict
@@ -363,9 +363,7 @@ def main():
     intersight = IntersightModule(module)
     intersight.result['api_response'] = {}
     intersight.result['trace_id'] = ''
-    #
-    # Argument spec above, resource path, and API body should be the only code changed in each policy module
-    #
+
     # Resource path used to configure policy
     resource_path = '/boot/PrecisionPolicies'
     # Define API body used in compares or create
