@@ -290,7 +290,7 @@ EXAMPLES = """
           facility: local6
           use_vrf: default
       origin_id:
-        hostname: True
+        hostname: true
 
 # Task output
 # -------------
@@ -576,7 +576,7 @@ EXAMPLES = """
           facility: local6
           use_vrf: default
       origin_id:
-        hostname: True
+        hostname: true
 
 # Task Output (redacted)
 # -----------------------
