@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 # Dell OpenManage Ansible Modules
-# Version 9.1.0
-# Copyright (C) 2022-2024 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.12.2
+# Copyright (C) 2022-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # Redistribution and use in source and binary forms, with or without modification,
 # are permitted provided that the following conditions are met:
@@ -36,6 +36,8 @@ RESET_SUCCESS = "iDRAC has been reset successfully."
 RESET_FAIL = "Unable to reset the iDRAC. For changes to reflect, manually reset the iDRAC."
 INVALID_ID_MSG = "Unable to complete the operation because " + \
                  "the value `{0}` for the input  `{1}` parameter is invalid."
+UNSUPPORTED_LC_STATUS_MSG = "Lifecycle controller status check is not supported."
+LC_STATUS_MSG = "Lifecycle controller status check is {lc_status} after {retries} number of retries, Exiting.."
 SYSTEM_ID = "System.Embedded.1"
 MANAGER_ID = "iDRAC.Embedded.1"
 SYSTEMS_URI = "/redfish/v1/Systems"
@@ -43,17 +45,33 @@ MANAGERS_URI = "/redfish/v1/Managers"
 CHASSIS_URI = "/redfish/v1/Chassis"
 IDRAC_RESET_URI = "/redfish/v1/Managers/{res_id}/Actions/Manager.Reset"
 SYSTEM_RESET_URI = "/redfish/v1/Systems/{res_id}/Actions/ComputerSystem.Reset"
-MANAGER_JOB_URI = "/redfish/v1/Managers/iDRAC.Embedded.1/Jobs?$expand=*($levels=1)"
-MANAGER_JOB_ID_URI = "/redfish/v1/Managers/iDRAC.Embedded.1/Jobs/{0}"
+MANAGER_JOB_URI = "/redfish/v1/Managers/iDRAC.Embedded.1/Oem/Dell/Jobs?$expand=*($levels=1)"
+MANAGER_JOB_ID_URI = "/redfish/v1/Managers/iDRAC.Embedded.1/Oem/Dell/Jobs/{0}"
+MANAGER_JOB_URI_10 = "/redfish/v1/Managers/iDRAC.Embedded.1/Oem/Dell/Jobs?$expand=*($levels=1)"
+MANAGER_JOB_ID_URI_10 = "/redfish/v1/Managers/iDRAC.Embedded.1/Oem/Dell/Jobs/{0}"
 GET_IDRAC_FIRMWARE_VER_URI = "/redfish/v1/Managers/iDRAC.Embedded.1?$select=FirmwareVersion"
 HOSTNAME_REGEX = r"^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$"
+OME_INFO = "ApplicationService/Info"
+ODATA_ID = "@odata.id"
+POWER_CHECK_RETRIES = 30
+POWER_CHECK_INTERVAL = 10
+GET_IDRAC_FIRMWARE_DETAILS_URI_10 = "/redfish/v1/UpdateService/Oem/Dell/DellSoftwareInventory?$select=Members"
+GET_IDRAC_FIRMWARE_URI_10 = "/redfish/v1/UpdateService/Oem/Dell/DellSoftwareInventory"
+TIMEOUT_NEGATIVE_OR_ZERO_MSG = "The value for the 'job_wait_timeout' parameter cannot be negative or zero."
+INVALID_TIME_FORMAT_MSG = "Invalid value for time. Enter the value in positive integer."
 
 import time
 from datetime import datetime
+from inspect import getfullargspec
 import re
 from ansible.module_utils.six.moves.urllib.error import HTTPError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
+from ansible_collections.dellemc.openmanage.plugins.module_utils.\
+    idrac_utils.info.firmware import IDRACFirmwareInfo
+import logging
+from ansible_collections.dellemc.openmanage.plugins.module_utils.logging_handler \
+    import CustomRotatingFileHandler
 
 
 def strip_substr_dict(odata_dict, chkstr='@odata.', case_sensitive=False):
@@ -318,7 +336,7 @@ def get_manager_res_id(idrac):
     try:
         resp = idrac.invoke_request(MANAGERS_URI, "GET")
         membs = resp.json_data.get("Members")
-        res_uri = membs[0].get('@odata.id')
+        res_uri = membs[0].get(ODATA_ID)
         res_id = res_uri.split("/")[-1]
     except HTTPError:
         res_id = MANAGER_ID
@@ -355,13 +373,16 @@ def idrac_system_reset(idrac, res_id, payload=None, job_wait=True, wait_time_sec
     track_failed, reset, job_resp = True, False, {}
     reset_msg = RESET_UNTRACK
     try:
-        idrac.invoke_request(SYSTEM_RESET_URI.format(res_id=res_id), 'POST', data=payload)
+        resp = idrac.invoke_request(SYSTEM_RESET_URI.format(res_id=res_id), 'POST', data=payload)
+        if resp.status_code == 204:
+            reset = True
+            return reset, track_failed, reset_msg, job_resp
         time.sleep(10)
         if wait_time_sec:
-            resp = idrac.invoke_request(MANAGER_JOB_URI, "GET")
-            job = list(filter(lambda d: d["JobState"] in ["RebootPending"], resp.json_data["Members"]))
+            resp = idrac.invoke_request(MANAGER_JOB_URI_10, "GET")
+            job = list(filter(lambda d: d["JobState"] in ["RebootPending", "RebootCompleted"], resp.json_data["Members"]))
             if job:
-                job_resp, msg = wait_for_idrac_job_completion(idrac, MANAGER_JOB_ID_URI.format(job[0]["Id"]),
+                job_resp, msg = wait_for_idrac_job_completion(idrac, MANAGER_JOB_ID_URI_10.format(job[0]["Id"]),
                                                               job_wait=job_wait, wait_timeout=wait_time_sec)
                 if "job is not complete" in msg:
                     reset, reset_msg = False, msg
@@ -383,7 +404,7 @@ def get_system_res_id(idrac):
                     "does not exist or is not implemented."
     else:
         member = resp.json_data.get("Members")
-        res_uri = member[0].get('@odata.id')
+        res_uri = member[0].get(ODATA_ID)
         res_id = res_uri.split("/")[-1]
     return res_id, error_msg
 
@@ -435,7 +456,7 @@ def wait_for_redfish_reboot_job(redfish_obj, res_id, payload=None, wait_time_sec
         resp = redfish_obj.invoke_request('POST', SYSTEM_RESET_URI.format(res_id=res_id), data=payload, api_timeout=120)
         time.sleep(10)
         if wait_time_sec and resp.status_code == 204:
-            resp = redfish_obj.invoke_request("GET", MANAGER_JOB_URI)
+            resp = redfish_obj.invoke_request("GET", get_job_uri(redfish_obj))
             reboot_job_lst = list(filter(lambda d: (d["JobType"] in ["RebootNoForce"]), resp.json_data["Members"]))
             job_resp = max(reboot_job_lst, key=lambda d: datetime.strptime(d["StartTime"], "%Y-%m-%dT%H:%M:%S"))
             if job_resp:
@@ -447,11 +468,16 @@ def wait_for_redfish_reboot_job(redfish_obj, res_id, payload=None, wait_time_sec
     return job_resp, reset, msg
 
 
-def wait_for_redfish_job_complete(redfish_obj, job_uri, job_wait=True, wait_timeout=120, sleep_time=10):
+def is_job_complete(percent_complete, job_state, check_completion):
+    return percent_complete == 100 and (not check_completion or job_state in {"Completed", "Failed"})
+
+
+def wait_for_redfish_job_complete(redfish_obj, job_uri, job_wait=True, wait_timeout=120, sleep_time=10, check_completion=False):
     max_sleep_time = wait_timeout
     sleep_interval = sleep_time
     job_msg = "The job is not complete after {0} seconds.".format(wait_timeout)
     job_resp = {}
+
     if job_wait:
         while max_sleep_time:
             if max_sleep_time > sleep_interval:
@@ -461,21 +487,28 @@ def wait_for_redfish_job_complete(redfish_obj, job_uri, job_wait=True, wait_time
                 max_sleep_time = 0
             time.sleep(sleep_interval)
             job_resp = redfish_obj.invoke_request("GET", job_uri, api_timeout=120)
-            if job_resp.json_data.get("PercentComplete") == 100:
+            job_data = job_resp.json_data
+            job_state = job_data.get("JobState")
+            percent_complete = job_data.get("PercentComplete")
+
+            if is_job_complete(percent_complete, job_state, check_completion):
                 time.sleep(10)
                 return job_resp, ""
-            if job_resp.json_data.get("JobState") == "RebootFailed":
+            if job_state == "RebootFailed":
                 time.sleep(10)
                 return job_resp, job_msg
     else:
         time.sleep(10)
         job_resp = redfish_obj.invoke_request("GET", job_uri, api_timeout=120)
         return job_resp, ""
+
     return job_resp, job_msg
 
 
 def get_dynamic_uri(idrac_obj, base_uri, search_label=''):
-    resp = idrac_obj.invoke_request(method='GET', uri=base_uri).json_data
+    args = getfullargspec(idrac_obj.invoke_request)[0]
+    data = {'uri': base_uri} if 'uri' in args else {'path': base_uri}
+    resp = idrac_obj.invoke_request(method='GET', **data).json_data
     if search_label:
         if search_label in resp:
             return resp[search_label]
@@ -484,19 +517,19 @@ def get_dynamic_uri(idrac_obj, base_uri, search_label=''):
 
 
 def get_scheduled_job_resp(idrac_obj, job_type):
-    # job_type can be like 'NICConfiguration' or 'BIOSConfiguration'
-    job_resp = {}
-    job_list = idrac_obj.invoke_request(
-        MANAGER_JOB_URI, "GET").json_data.get('Members', [])
-    for each_job in job_list:
-        if each_job.get("JobType") == job_type and each_job.get("JobState") in ["Scheduled", "Running", "Starting"]:
-            job_resp = each_job
-            break
-    return job_resp
+    job_state = {"Scheduled", "New", "Running"}
+    args = getfullargspec(idrac_obj.invoke_request)[0]
+    data = {'uri': get_job_uri(idrac_obj)} if 'uri' in args else {'path': get_job_uri(idrac_obj)}
+    job_list = idrac_obj.invoke_request(method="GET", **data).json_data.get('Members', [])
+    if isinstance(job_type, str):
+        job_resp = next((j for j in job_list if (j.get("JobState") in job_state) and (j.get("JobType") == job_type)), {})
+    elif isinstance(job_type, list):
+        job_resp = next((j for j in job_list if (j.get("JobState") in job_state) and (j.get("JobType") in job_type)), {})
+    return remove_key(job_resp, regex_pattern='(.*?)@odata')
 
 
 def delete_job(idrac_obj, job_id):
-    resp = idrac_obj.invoke_request(uri=MANAGER_JOB_ID_URI.format(job_id), method="DELETE")
+    resp = idrac_obj.invoke_request(uri=get_job_uri_id(idrac_obj).format(job_id), method="DELETE")
     return resp.json_data
 
 
@@ -520,25 +553,280 @@ def xml_data_conversion(attr_dict, fqdd=None, custom_payload_to_add=None):
     return root
 
 
-def validate_and_get_first_resource_id_uri(module, idrac, base_uri):
-    odata = '@odata.id'
+def validate_and_get_first_resource_id_uri(resource_id, idrac, base_uri):
     found = False
     res_id_uri = None
-    res_id_input = module.params.get('resource_id')
+    if resource_id and not isinstance(resource_id, str):
+        resource_id = resource_id.params.get('resource_id')
     res_id_members = get_dynamic_uri(idrac, base_uri, 'Members')
     for each in res_id_members:
-        if res_id_input and res_id_input == each[odata].split('/')[-1]:
-            res_id_uri = each[odata]
+        if resource_id and resource_id == each[ODATA_ID].split('/')[-1]:
+            res_id_uri = each[ODATA_ID]
             found = True
             break
-    if not found and res_id_input:
+    if not found and resource_id:
         return res_id_uri, INVALID_ID_MSG.format(
-            res_id_input, 'resource_id')
-    elif res_id_input is None:
-        res_id_uri = res_id_members[0][odata]
+            resource_id, 'resource_id')
+    elif resource_id is None:
+        res_id_uri = res_id_members[0][ODATA_ID]
     return res_id_uri, ''
 
 
 def get_idrac_firmware_version(idrac):
-    firm_version = idrac.invoke_request(method='GET', uri=GET_IDRAC_FIRMWARE_VER_URI)
+    args = getfullargspec(idrac.invoke_request)[0]
+    data = {'uri': GET_IDRAC_FIRMWARE_VER_URI} if 'uri' in args else {'path': GET_IDRAC_FIRMWARE_VER_URI}
+    firm_version = idrac.invoke_request(method='GET', **data)
     return firm_version.json_data.get('FirmwareVersion', '')
+
+
+def get_ome_version(ome_obj):
+    resp = ome_obj.invoke_request('GET', OME_INFO)
+    return resp.json_data.get("Version")
+
+
+def trigger_restart_operation(idrac, restart_type="GracefulRestart", resource_id=None):
+    resp, error_msg = {}, {}
+    uri, error_msg = validate_and_get_first_resource_id_uri(resource_id, idrac, SYSTEMS_URI)
+    if error_msg:
+        return resp, error_msg
+    actions_uri = get_dynamic_uri(idrac, uri, 'Actions').get("#ComputerSystem.Reset", {}).get("target", '')
+    payload = {"ResetType": restart_type}
+    resp = idrac.invoke_request(method='POST', uri=actions_uri, data=payload)
+    return resp, error_msg
+
+
+def wait_for_lc_status(idrac, job_wait_timeout=300, resource_id=None, interval=10):
+    lc_status_completed, error_msg = False, ''
+    lcstatus = ""
+    retry_count = 1
+    # LCStatus remain 'Ready' even after triggering restart
+    # so waiting few seconds before loop
+    waiting_before_lc_status_check = 12 * interval
+    if job_wait_timeout >= waiting_before_lc_status_check:
+        time.sleep(waiting_before_lc_status_check)
+        job_wait_timeout = job_wait_timeout - waiting_before_lc_status_check
+    max_idrac_reset_try = job_wait_timeout // interval
+    uri, error_msg = validate_and_get_first_resource_id_uri(resource_id, idrac, MANAGERS_URI)
+    if error_msg:
+        return lc_status_completed, error_msg
+    resp = get_dynamic_uri(idrac, uri, "Links")
+    url = resp.get("Oem", {}).get("Dell", {}).get('DellLCService', {}).get(ODATA_ID, {})
+    if url:
+        action_resp = get_dynamic_uri(idrac, url)
+        lc_url = action_resp.get('Actions', {}).get('#DellLCService.GetRemoteServicesAPIStatus', {}).get('target', {})
+    else:
+        return lc_status_completed, UNSUPPORTED_LC_STATUS_MSG
+    lc_resp = idrac.invoke_request(lc_url, "POST", data="{}", dump=False)
+    lcstatus = lc_resp.json_data.get('LCStatus')
+    while retry_count < max_idrac_reset_try:
+        try:
+            lc_resp = idrac.invoke_request(lc_url, "POST", data="{}", dump=False)
+            lcstatus = lc_resp.json_data.get('LCStatus')
+            if lcstatus == 'Ready':
+                lc_status_completed = True
+                break
+            time.sleep(interval)
+            retry_count = retry_count + 1
+        except URLError:
+            time.sleep(interval)
+            retry_count = retry_count + 1
+            if retry_count == max_idrac_reset_try:
+                error_msg = LC_STATUS_MSG.format(lc_status='unreachable', retries=max_idrac_reset_try)
+                break
+    if retry_count == max_idrac_reset_try and lcstatus != "Ready":
+        error_msg = LC_STATUS_MSG.format(lc_status=lcstatus, retries=retry_count)
+    return lc_status_completed, error_msg
+
+
+def get_lc_log_or_current_log_time(idrac, curr_time=None, lc_log_ids_list=None, resource_id=None):
+    lc_log_found = False
+    msg = "No LC log found."
+
+    uri, error_msg = validate_and_get_first_resource_id_uri(
+        resource_id, idrac, MANAGERS_URI
+    )
+    if error_msg:
+        return lc_log_found, error_msg
+
+    log_services_uri = get_dynamic_uri(idrac, uri, "LogServices").get(
+        ODATA_ID, {}
+    )
+    log_svc_member = get_dynamic_uri(idrac, log_services_uri, "Members")
+    log_lc_uri = [
+        each[ODATA_ID]
+        for each in log_svc_member
+        if each[ODATA_ID].split("/")[-1] == "Lclog"
+    ][0]
+    log_entries_uri = get_dynamic_uri(
+        idrac, log_lc_uri, "Entries"
+    ).get(ODATA_ID, {})
+
+    try:
+        resp = idrac.invoke_request(log_lc_uri, "GET")
+        logs_list = idrac.invoke_request(log_entries_uri, "GET").json_data.get(
+            "Members"
+        )
+
+        if not curr_time:
+            curr_time = resp.json_data.get("DateTime")
+
+        if not lc_log_ids_list:
+            return curr_time
+
+        for log in logs_list:
+            if log.get("Created") >= curr_time:
+                for err_id in lc_log_ids_list:
+                    if err_id in log.get("MessageId"):
+                        lc_log_found = True
+                        msg = log.get("Message")
+                        break
+
+    except Exception:
+        msg = "No LC log found."
+
+    return lc_log_found, msg
+
+
+def expand_ipv6(ip):
+    sections = ip.split(':')
+    num_sections = len(sections)
+    double_colon_index = sections.index('') if '' in sections else -1
+    if double_colon_index != -1:
+        missing_sections = 8 - num_sections + 1
+        sections[double_colon_index:double_colon_index + 1] = ['0000'] * missing_sections
+    sections = [section.zfill(4) for section in sections]
+    expanded_ip = ':'.join(sections)
+    return expanded_ip
+
+
+def cert_file_format_string(ip, prefix="",
+                            postfix="",
+                            datetime_format="%Y%m%d_%H%M%S"):
+    now = datetime.now()
+    hostname = expand_ipv6(ip).replace(":", ".")
+    data = f"{prefix}{hostname}_{now.strftime(datetime_format)}{postfix}"
+    return data
+
+
+def track_power_state(idrac, base_uri, desired_state, retries=POWER_CHECK_RETRIES, interval=POWER_CHECK_INTERVAL):
+    count = retries
+    while count:
+        ps = get_power_state(idrac, base_uri)
+        if ps in desired_state:
+            achieved = True
+            break
+        else:
+            time.sleep(interval)
+        count = count - 1
+    else:
+        achieved = False
+    return achieved
+
+
+def get_power_state(idrac, base_uri):
+    retries = 10
+    pstate = "Unknown"
+    while retries > 0:
+        try:
+            resp = idrac.invoke_request(base_uri, "GET")
+            pstate = resp.json_data.get("PowerState")
+            break
+        except Exception:
+            retries = retries - 1
+    return pstate
+
+
+def power_act_host(idrac, system_uri, p_state):
+    try:
+        _resp, error_msg = {}, {}
+        uri, error_msg = validate_and_get_first_resource_id_uri(None, idrac, system_uri)
+        if error_msg:
+            return False
+        actions_uri = get_dynamic_uri(idrac, uri, 'Actions').get("#ComputerSystem.Reset", {}).get("target", '')
+        idrac.invoke_request(actions_uri, "POST", data={'ResetType': p_state})
+        p_act = True
+    except HTTPError:
+        p_act = False
+    return p_act
+
+
+def reset_host(idrac, restart_type, system_uri, base_uri):
+    p_state = 'On'
+    ps = get_power_state(idrac, base_uri)
+    on_state = ["On"]
+    if ps in on_state:
+        p_state = 'GracefulShutdown'
+        if 'Force' in restart_type:
+            p_state = 'ForceOff'
+        p_act = power_act_host(idrac, system_uri, p_state)
+        if not p_act:
+            return False
+        state_achieved = track_power_state(idrac, base_uri, ["Off"])
+        p_state = "On"
+        if not state_achieved:
+            time.sleep(10)
+            p_state = "ForceRestart"
+    p_act = power_act_host(idrac, system_uri, p_state)
+    if not p_act:
+        return False
+    state_achieved = track_power_state(idrac, base_uri, on_state)
+    return state_achieved
+
+
+def validate_job_wait(module):
+    """
+    Validates job_wait and job_wait_timeout parameters.
+    :param module: The Ansible module instance.
+    :param job_wait_param: The name of the job wait parameter to check (default is "job_wait").
+    :param job_wait_timeout_param: The name of the job wait timeout parameter to check (default is "job_wait_timeout").
+    """
+    job_wait = module.params.get('job_wait')
+    job_wait_timeout = module.params.get('job_wait_timeout')
+
+    if job_wait and (job_wait_timeout is None or job_wait_timeout <= 0):
+        return True
+
+    return False
+
+
+def validate_time(time, module):
+    # Ensure the time is a string (or cast it to a string if it's not)
+    if not isinstance(time, str):
+        module.exit_json(msg="Time must be a string in HH:MM format", failed=True)
+
+    # Check if the time matches the 24-hour format (HH:MM)
+    if time and not re.match(r"^(?:[01]\d|2[0-3]):[0-5]\d$", time):
+        module.exit_json(msg=INVALID_TIME_FORMAT_MSG, failed=True)
+
+
+def get_job_uri_id(rest_obj):
+    firmware_obj = IDRACFirmwareInfo(rest_obj)
+    job_uri_id = MANAGER_JOB_ID_URI
+    if not firmware_obj.is_omsdk_required():
+        job_uri_id = MANAGER_JOB_ID_URI_10
+    return job_uri_id
+
+
+def get_job_uri(rest_obj):
+    firmware_obj = IDRACFirmwareInfo(rest_obj)
+    job_uri = MANAGER_JOB_URI
+    if not firmware_obj.is_omsdk_required():
+        job_uri = MANAGER_JOB_URI_10
+    return job_uri
+
+
+def get_logger(module_name, log_file_name='ansible_openmanage.log',
+               log_devel=logging.INFO):
+    FORMAT = '%(asctime)-15s %(filename)s %(levelname)s : %(message)s'
+    max_bytes = 5 * 1024 * 1024
+    logging.basicConfig(filename=log_file_name, format=FORMAT)
+    LOG = logging.getLogger(module_name)
+    LOG.setLevel(log_devel)
+    handler = CustomRotatingFileHandler(log_file_name,
+                                        maxBytes=max_bytes,
+                                        backupCount=5)
+    formatter = logging.Formatter(FORMAT)
+    handler.setFormatter(formatter)
+    LOG.addHandler(handler)
+    LOG.propagate = False
+    return LOG
