@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -148,6 +151,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -156,8 +160,8 @@ EXAMPLES = '''
     - name: Anti-spam black/white list entries.
       fortinet.fortimanager.fmgr_emailfilter_bwl_entries:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -230,6 +234,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'bwl': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'emailfilter_bwl_entries': {
             'type': 'dict',
             'v_range': [['6.2.0', '']],
