@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -89,9 +92,10 @@ options:
         required: false
         type: dict
         suboptions:
-            allow-routing:
+            allow_routing:
+                aliases: ['allow-routing']
                 type: str
-                description: Deprecated, please rename it to allow_routing. Enable/disable use of this group in the static route configuration.
+                description: Enable/disable use of this group in the static route configuration.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -100,16 +104,16 @@ options:
                 description: Color of icon on the GUI.
             comment:
                 type: raw
-                description: (dict or str) No description.
+                description: (dict or str) Comment.
             dynamic_mapping:
                 type: list
                 elements: dict
-                description: Dynamic_Mapping.
+                description: Dynamic mapping.
                 suboptions:
                     _scope:
                         type: list
                         elements: dict
-                        description: _Scope.
+                        description: Scope.
                         suboptions:
                             name:
                                 type: str
@@ -117,49 +121,53 @@ options:
                             vdom:
                                 type: str
                                 description: Vdom.
-                    allow-routing:
+                    allow_routing:
+                        aliases: ['allow-routing']
                         type: str
-                        description: Deprecated, please rename it to allow_routing. Enable/disable use of this group in the static route configuration.
+                        description: Allow routing.
                         choices:
                             - 'disable'
                             - 'enable'
                     color:
                         type: int
-                        description: Color of icon on the GUI.
+                        description: Color.
                     comment:
                         type: raw
-                        description: (dict or str) No description.
+                        description: (dict or str) Comment.
                     exclude:
                         type: str
-                        description: Enable/disable address exclusion.
+                        description: Exclude.
                         choices:
                             - 'disable'
                             - 'enable'
-                    exclude-member:
+                    exclude_member:
+                        aliases: ['exclude-member']
                         type: raw
-                        description: (list or str) Deprecated, please rename it to exclude_member. Address exclusion member.
+                        description: (list or str) Exclude member.
                     member:
                         type: list
                         elements: str
-                        description: Address objects contained within the group.
+                        description: Member.
                     tags:
                         type: raw
                         description: (list or str) Tags.
                     uuid:
                         type: str
-                        description: Universally Unique Identifier
+                        description: Uuid.
                     visibility:
                         type: str
-                        description: Enable/disable address visibility in the GUI.
+                        description: Visibility.
                         choices:
                             - 'disable'
                             - 'enable'
-                    _image-base64:
+                    _image_base64:
+                        aliases: ['_image-base64']
                         type: str
-                        description: Deprecated, please rename it to _image_base64. _Image-Base64.
-                    global-object:
+                        description: Image base64.
+                    global_object:
+                        aliases: ['global-object']
                         type: int
-                        description: Deprecated, please rename it to global_object. Global-Object.
+                        description: Global object.
                     type:
                         type: str
                         description: Type.
@@ -167,9 +175,10 @@ options:
                             - 'default'
                             - 'array'
                             - 'folder'
-                    fabric-object:
+                    fabric_object:
+                        aliases: ['fabric-object']
                         type: str
-                        description: Deprecated, please rename it to fabric_object. Security Fabric global object setting.
+                        description: Security Fabric global object setting.
                         choices:
                             - 'disable'
                             - 'enable'
@@ -217,18 +226,21 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            exclude-member:
+            exclude_member:
+                aliases: ['exclude-member']
                 type: raw
-                description: (list or str) Deprecated, please rename it to exclude_member. Address exclusion member.
+                description: (list or str) Address exclusion member.
             tags:
                 type: str
                 description: Name
-            _image-base64:
+            _image_base64:
+                aliases: ['_image-base64']
                 type: str
-                description: Deprecated, please rename it to _image_base64. _Image-Base64.
-            global-object:
+                description: Image base64.
+            global_object:
+                aliases: ['global-object']
                 type: int
-                description: Deprecated, please rename it to global_object. Global Object.
+                description: Global Object.
             type:
                 type: str
                 description: Address group type.
@@ -236,9 +248,10 @@ options:
                     - 'default'
                     - 'array'
                     - 'folder'
-            fabric-object:
+            fabric_object:
+                aliases: ['fabric-object']
                 type: str
-                description: Deprecated, please rename it to fabric_object. Security Fabric global object setting.
+                description: Security Fabric global object setting.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -254,6 +267,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -266,7 +280,7 @@ EXAMPLES = '''
         adom: ansible
         state: present
         firewall_addrgrp:
-          allow-routing: disable
+          allow_routing: disable
           color: 0
           member: "ansible-test1" # IPv4 address name
           name: "ansible-addrgrp4" # could not the same with other group, adress name, including IPv6 group and address
@@ -331,27 +345,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/addrgrp',
         '/pm/config/global/obj/firewall/addrgrp'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/addrgrp/{addrgrp}',
-        '/pm/config/global/obj/firewall/addrgrp/{addrgrp}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_addrgrp': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -388,17 +395,16 @@ def main():
                     'elements': 'dict'
                 },
                 'uuid': {'type': 'str'},
-                'visibility': {'choices': ['disable', 'enable'], 'type': 'str'},
+                'visibility': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'exclude': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'exclude-member': {'v_range': [['6.2.0', '']], 'type': 'raw'},
-                'tags': {'v_range': [['6.2.0', '6.4.14']], 'type': 'str'},
+                'tags': {'v_range': [['6.2.0', '6.4.15']], 'type': 'str'},
                 '_image-base64': {'v_range': [['6.2.2', '']], 'type': 'str'},
                 'global-object': {'v_range': [['6.4.0', '']], 'type': 'int'},
                 'type': {'v_range': [['6.4.0', '']], 'choices': ['default', 'array', 'folder'], 'type': 'str'},
                 'fabric-object': {'v_range': [['6.4.4', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'category': {'v_range': [['7.0.0', '']], 'choices': ['default', 'ztna-ems-tag', 'ztna-geo-tag'], 'type': 'str'}
             }
-
         }
     }
 
@@ -407,17 +413,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_addrgrp'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
