@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -240,6 +243,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -248,32 +252,32 @@ EXAMPLES = '''
     - name: Configure SSL options.
       fortinet.fortimanager.fmgr_firewall_sslsshprofile_ssl:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         ssl_ssh_profile: <your own value>
         firewall_sslsshprofile_ssl:
-          allow_invalid_server_cert: <value in [disable, enable]>
-          client_cert_request: <value in [bypass, inspect, block]>
-          inspect_all: <value in [disable, certificate-inspection, deep-inspection]>
-          unsupported_ssl: <value in [bypass, inspect, block]>
-          untrusted_cert: <value in [allow, block, ignore]>
-          invalid_server_cert: <value in [allow, block]>
-          sni_server_cert_check: <value in [disable, enable, strict]>
-          untrusted_server_cert: <value in [allow, block, ignore]>
-          cert_validation_failure: <value in [allow, block, ignore]>
-          cert_validation_timeout: <value in [allow, block, ignore]>
-          client_certificate: <value in [bypass, inspect, block]>
-          expired_server_cert: <value in [allow, block, ignore]>
-          revoked_server_cert: <value in [allow, block, ignore]>
-          unsupported_ssl_cipher: <value in [allow, block]>
-          unsupported_ssl_negotiation: <value in [allow, block]>
-          cert_probe_failure: <value in [block, allow]>
-          min_allowed_ssl_version: <value in [ssl-3.0, tls-1.0, tls-1.1, ...]>
-          unsupported_ssl_version: <value in [block, allow, inspect]>
-          encrypted_client_hello: <value in [block, allow]>
+          # allow_invalid_server_cert: <value in [disable, enable]>
+          # client_cert_request: <value in [bypass, inspect, block]>
+          # inspect_all: <value in [disable, certificate-inspection, deep-inspection]>
+          # unsupported_ssl: <value in [bypass, inspect, block]>
+          # untrusted_cert: <value in [allow, block, ignore]>
+          # invalid_server_cert: <value in [allow, block]>
+          # sni_server_cert_check: <value in [disable, enable, strict]>
+          # untrusted_server_cert: <value in [allow, block, ignore]>
+          # cert_validation_failure: <value in [allow, block, ignore]>
+          # cert_validation_timeout: <value in [allow, block, ignore]>
+          # client_certificate: <value in [bypass, inspect, block]>
+          # expired_server_cert: <value in [allow, block, ignore]>
+          # revoked_server_cert: <value in [allow, block, ignore]>
+          # unsupported_ssl_cipher: <value in [allow, block]>
+          # unsupported_ssl_negotiation: <value in [allow, block]>
+          # cert_probe_failure: <value in [block, allow]>
+          # min_allowed_ssl_version: <value in [ssl-3.0, tls-1.0, tls-1.1, ...]>
+          # unsupported_ssl_version: <value in [block, allow, inspect]>
+          # encrypted_client_hello: <value in [block, allow]>
 '''
 
 RETURN = '''
@@ -332,16 +336,17 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'ssl-ssh-profile': {'type': 'str', 'api_name': 'ssl_ssh_profile'},
         'ssl_ssh_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_sslsshprofile_ssl': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {
                 'allow-invalid-server-cert': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'client-cert-request': {'choices': ['bypass', 'inspect', 'block'], 'type': 'str'},
+                'client-cert-request': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['bypass', 'inspect', 'block'], 'type': 'str'},
                 'inspect-all': {'choices': ['disable', 'certificate-inspection', 'deep-inspection'], 'type': 'str'},
-                'unsupported-ssl': {'choices': ['bypass', 'inspect', 'block'], 'type': 'str'},
+                'unsupported-ssl': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['bypass', 'inspect', 'block'], 'type': 'str'},
                 'untrusted-cert': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['allow', 'block', 'ignore'], 'type': 'str'},
-                'invalid-server-cert': {'v_range': [['6.2.0', '']], 'choices': ['allow', 'block'], 'type': 'str'},
+                'invalid-server-cert': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['allow', 'block'], 'type': 'str'},
                 'sni-server-cert-check': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable', 'strict'], 'type': 'str'},
                 'untrusted-server-cert': {'v_range': [['6.2.0', '']], 'choices': ['allow', 'block', 'ignore'], 'type': 'str'},
                 'cert-validation-failure': {'v_range': [['6.4.0', '']], 'choices': ['allow', 'block', 'ignore'], 'type': 'str'},
