@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -111,6 +114,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -119,8 +123,8 @@ EXAMPLES = '''
     - name: User group dynamic mapping sslvpn os check list
       fortinet.fortimanager.fmgr_user_group_dynamicmapping_sslvpnoschecklist:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -189,6 +193,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'group': {'required': True, 'type': 'str'},
         'dynamic_mapping': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'user_group_dynamicmapping_sslvpnoschecklist': {
             'type': 'dict',
             'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']],
